pub fn validate_public_key(
pk: &ThresholdPublicKey,
) -> Result<(), FrostMlDsaError>Expand description
Validate that a public key has the correct length for ML-DSA-65.
pub fn validate_public_key(
pk: &ThresholdPublicKey,
) -> Result<(), FrostMlDsaError>Validate that a public key has the correct length for ML-DSA-65.